Alexis' log

# Archives for Alexis' log

30 novembre 2012
  FILENAME_METADATA example
29 février 2012
  Second article
20 avril 2011
  A markdown powered article
17 février 2011
  Article 1
17 février 2011
  Article 2
17 février 2011
  Article 3
02 décembre 2010
  This is a super article !
20 octobre 2010
  Oh yeah !
15 octobre 2010
  Unbelievable !
14 mars 2010
  The baz tag

## links

- Biologeek
- Filyb
- Libert-fr
- N1k0
- Tarek Ziadé
- Zubin Mithra

## social

- atom feed
- rss feed
- twitter
- lastfm
- github